@@ -455,11 +455,11 @@ updateSnowTextures (CompScreen *s)
 				&ss->snowTex[count].height);
 	if (!ss->snowTex[count].loaded)
 	{
-	    compLogMessage (s->display, "snow", CompLogLevelWarn,
+	    compLogMessage ("snow", CompLogLevelWarn,
 			    "Texture not found : %s", sd->snowTexFiles[i].s);
 	    continue;
 	}
-	compLogMessage (s->display, "snow", CompLogLevelInfo,
+	compLogMessage ("snow", CompLogLevelInfo,
 			"Loaded Texture %s", sd->snowTexFiles[i].s);
 	
 	mat = &ss->snowTex[count].tex.matrix;
@@ -539,6 +539,9 @@ snowInitScreen (CompPlugin *p,
     WRAP (ss, s, drawWindow, snowDrawWindow);
 
     ss->timeoutHandle = compAddTimeout (snowGetSnowUpdateDelay (s->display),
+					(float)
+					snowGetSnowUpdateDelay (s->display) *
+					1.2,
 					stepSnowPositions, s);
 
     return TRUE;
@@ -606,6 +609,7 @@ snowDisplayOptionChanged (CompDisplay        *d,
 		    compRemoveTimeout (ss->timeoutHandle);
 		ss->timeoutHandle =
 		    compAddTimeout (snowGetSnowUpdateDelay (d),
+				    (float) snowGetSnowUpdateDelay (d) * 1.2,
 				    stepSnowPositions, s);
 	    }
 	}
